@@ -1,7 +1,7 @@
 /* GStreamer
  * Copyright (C) 2007 Stefan Kost <ensonic@users.sf.net>
  *
- * gstdebugutils.c: debugging and analysis utillities
+ * gstdebugutils.c: debugging and analysis utilities
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,7 +21,7 @@
 /* TODO:
  * edge [ constraint=false ];
  *   this creates strange graphs ("minlen=0" is better)
- * try puting src/sink ghostpads for each bin into invisible clusters
+ * try putting src/sink ghostpads for each bin into invisible clusters
  *
  * for more compact nodes, try
  * - changing node-shape from box into record
@@ -34,6 +34,17 @@
  *     caps (simple caps = one line)
  */
 
+/**
+ * SECTION: debugutils
+ * @title: Debugging utilities
+ * @short_description: A set of utilities for debugging and development
+ *
+ * These utility functions help with generating dot graphs which can
+ * be rendered with [graphviz] to multiple formats.
+ *
+ * [graphviz]: https://graphviz.org/
+ */
+
 #include "gst_private.h"
 #include "gstdebugutils.h"
 
@@ -71,7 +82,8 @@ static const gchar spaces[] = {
 static gchar *
 debug_dump_make_object_name (GstObject * obj)
 {
-  return g_strcanon (g_strdup_printf ("%s_%p", GST_OBJECT_NAME (obj), obj),
+  /* must start with a letter to prevent dot from splitting names starting with [0-9] */
+  return g_strcanon (g_strdup_printf ("node_%s_%p", GST_OBJECT_NAME (obj), obj),
       G_CSET_A_2_Z G_CSET_a_2_z G_CSET_DIGITS "_", '_');
 }
 
@@ -118,7 +130,8 @@ debug_dump_get_object_params (GObject * object,
       /* skip some properties */
       if (!(property->flags & G_PARAM_READABLE))
         continue;
-      if (!strcmp (property->name, "name"))
+      if (!strcmp (property->name, "name")
+          || !strcmp (property->name, "parent"))
         continue;
 
       if (ignored_propnames)
@@ -230,8 +243,7 @@ debug_dump_pad (GstPad * pad, const gchar * color_name,
   GstPadPresence presence;
   gchar *pad_name, *param_name = NULL;
   const gchar *style_name;
-  static const char *const ignore_propnames[] =
-      { "parent", "direction", "template",
+  static const char *const ignore_propnames[] = { "direction", "template",
     "caps", NULL
   };
   const gchar *spc = MAKE_INDENT (indent);
@@ -614,6 +626,7 @@ debug_dump_element (GstBin * bin, GstDebugGraphDetails details,
   gchar *state_name = NULL;
   gchar *param_name = NULL;
   const gchar *spc = MAKE_INDENT (indent);
+  static const char *const ignore_propnames[] = { "stats", NULL };
 
   element_iter = gst_bin_iterate_elements (bin);
   elements_done = FALSE;
@@ -628,7 +641,7 @@ debug_dump_element (GstBin * bin, GstDebugGraphDetails details,
         }
         if (details & GST_DEBUG_GRAPH_SHOW_NON_DEFAULT_PARAMS) {
           param_name = debug_dump_get_object_params (G_OBJECT (element),
-              details, NULL);
+              details, ignore_propnames);
         }
         /* elements */
         g_string_append_printf (str, "%ssubgraph cluster_%s {\n", spc,
@@ -795,9 +808,10 @@ debug_dump_footer (GString * str)
 /**
  * gst_debug_bin_to_dot_data:
  * @bin: the top-level pipeline that should be analyzed
+ * @details: type of #GstDebugGraphDetails to use
  *
  * To aid debugging applications one can use this method to obtain the whole
- * network of gstreamer elements that form the pipeline into an dot file.
+ * network of gstreamer elements that form the pipeline into a dot file.
  * This data can be processed with graphviz to get an image.
  *
  * Returns: (transfer full): a string containing the pipeline in graphviz
@@ -822,14 +836,16 @@ gst_debug_bin_to_dot_data (GstBin * bin, GstDebugGraphDetails details)
 /**
  * gst_debug_bin_to_dot_file:
  * @bin: the top-level pipeline that should be analyzed
+ * @details: type of #GstDebugGraphDetails to use
  * @file_name: (type filename): output base filename (e.g. "myplayer")
  *
  * To aid debugging applications one can use this method to write out the whole
- * network of gstreamer elements that form the pipeline into an dot file.
+ * network of gstreamer elements that form the pipeline into a dot file.
  * This file can be processed with graphviz to get an image.
- * <informalexample><programlisting>
+ *
+ * ``` shell
  *  dot -Tpng -oimage.png graph_lowlevel.dot
- * </programlisting></informalexample>
+ * ```
  */
 void
 gst_debug_bin_to_dot_file (GstBin * bin, GstDebugGraphDetails details,
@@ -872,6 +888,7 @@ gst_debug_bin_to_dot_file (GstBin * bin, GstDebugGraphDetails details,
 /**
  * gst_debug_bin_to_dot_file_with_ts:
  * @bin: the top-level pipeline that should be analyzed
+ * @details: type of #GstDebugGraphDetails to use
  * @file_name: (type filename): output base filename (e.g. "myplayer")
  *
  * This works like gst_debug_bin_to_dot_file(), but adds the current timestamp
@@ -906,6 +923,13 @@ gst_debug_bin_to_dot_file_with_ts (GstBin * bin,
 }
 #else /* !GST_DISABLE_GST_DEBUG */
 #ifndef GST_REMOVE_DISABLED
+
+gchar *
+gst_debug_bin_to_dot_data (GstBin * bin, GstDebugGraphDetails details)
+{
+  return g_strdup ("");
+}
+
 void
 gst_debug_bin_to_dot_file (GstBin * bin, GstDebugGraphDetails details,
     const gchar * file_name)
